@@ -1,3 +1,25 @@
+class Contact(object):
+    name = None
+    occupation = None
+    url = None
+
+    def __init__(
+        self,
+        name=None,
+        occupation=None,
+        url=None
+    ):
+
+        self.name = name
+        self.occupation = occupation
+        self.url = url
+
+    def __repr__(self):
+        return "{name} ({occupation})".format(
+            name=self.name, occupation=self.occupation
+        )
+
+
 class Institution(object):
     institution_name = None
     website = None
